The Marine04 marine radiocarbon age calibration curve
on a calendar grid spanning from 50,000–0 cal yr BP
(Before Present, 0 cal yr BP corresponds to 1950 CE).
Note: This dataset provides \({}^{14}\)C ages and F\({}^{14}\)C values
on a calendar age grid. This is a different format from oxcal/calib .14c files
which give the \({}^{14}\)C ages and \({\Delta}^{14}\)C values.
Reference:
Hughen KA, Baillie MGL, Bard E, Beck JW,
Bertrand CJH, Blackwell PG, Buck CE, Burr GS, Cutler KB, Damon PE,
Edwards RL, Fairbanks RG, Friedrich M, Guilderson TP, Kromer B,
McCormac G, Manning S, Bronk Ramsey C, Reimer PJ, Reimer RW,
Remmele S, Southon JR, Stuiver M, Talamo S, Taylor FW,
van der Plicht J, Weyhenmeyer CE. 2004. Marine04 marine radiocarbon age calibration, 0-26 cal kyr BP.
Radiocarbon 46(3):1059-1086 https://doi.org/10.1017/s0033822200033002.
Format
marine04
A data frame with 3,301 rows and 5 columns providing the Marine04 radiocarbon age calibration curve on a calendar grid spanning from 50,000–0 cal yr BP:
- calendar_age
The calendar age (in cal yr BP)
- c14_age
The \({}^{14}\)C age (in \({}^{14}\)C yr BP)
- c14_sig
The (1\(\sigma\)) uncertainty in the \({}^{14}\)C age
- f14c
The \({}^{14}\)C age expressed as F\({}^{14}\)C concentration
- f14c_sig
The (1\(\sigma\)) uncertainty in the F\({}^{14}\)C concentration